import { useRoute } from 'vue-router'

// 棒线和堆垛类型
export enum MachineConfigType {
  RODLINE = 0,
  STACKING = 1,
}

// 棒线是否需要用车
export enum RODLINE_CAR_TYPE {
  NO_CAR = 0,
  NEED_CAR = 1,
}

// 棒线和堆垛字段名称
export const MACHINE_CONFIG_FIELD_NAME = {
  roll_club_one: 'rollcluboneNum',
  roll_club_two: 'rollclubtwoNum',
  roll_club_three: 'rollclubthreeNum',
  roll_height: 'rollheightNum',
  roll_out_shipp: 'rolloutshippNum',
  stacking: 'stackNum',
}

// 需要显示车牌号
export const NEED_SHOW_CAR_NUM = ['rollclubtwoNum', 'rollclubthreeNum', 'rolloutshippNum']

// 需要显示层数和位置的
export const NEED_SHOW_LAYER_POSITION = ['wasteNum', 'stackNum']

// 钢坯分组数
export const STEEL_GROUP_NUM = 4

// 钢坯堆垛最大层数
export const STEEL_MAX_LAYER_NUM = 20

// 钢坯堆垛最大位置数
export const STEEL_MAX_POSITION_NUM = 9

// 单层允许最大空位置数
export const MAX_EMPTY_POSITION_NUM = 2

// 限制显示层数的
export const DUOWEI_SHOW_LAYERS = {
  // '9': [4], // 步进冷床只显示4层
}

// 不限制4个为一组的目的地
export const NO_LIMIT_GROUP_DESTINATION = ['roll_club_one']

// 非用车目的地，在垛位装车时需要显示的
export const NO_CAR_DESTINATION = ['15']

// 堆垛装车去高线不包含的垛位
export const NO_HIGH_LINE_DESTINATION = ['6']

// 数组按照指定数量分组
export const groupArray = (arr: unknown[], num: number) => {
  const result: unknown[] = []
  for (let i = 0; i < arr.length; i += num) {
    result.push(arr.slice(i, i + num))
  }
  return result
}

// 数组去重
export const uniqueArray = (arr: unknown[]) => {
  return Array.isArray(arr) ? [...new Set(arr)] : []
}

// 五号机所有目的地、堆垛配置信息
export const configAll5 = [
  {
    id: '1',
    createBy: 'admin',
    createTime: '2024-11-19 08:56:03',
    updateBy: null,
    updateTime: null,
    sysOrgCode: null,
    castMachine: '5',
    typeName: '棒一',
    belongType: 0,
    isTrucking: 0,
    remark: null,
    belongTable: 'roll_club_one',
  },
  {
    id: '10',
    createBy: 'admin',
    createTime: '2024-11-19 09:09:23',
    updateBy: null,
    updateTime: null,
    sysOrgCode: null,
    castMachine: '5',
    typeName: '501堆垛',
    belongType: 1,
    isTrucking: 0,
    remark: null,
    belongTable: 'stacking_and_loading_vehicles',
  },
  {
    id: '2',
    createBy: 'admin',
    createTime: '2024-11-19 08:56:03',
    updateBy: null,
    updateTime: null,
    sysOrgCode: null,
    castMachine: '5',
    typeName: '棒二',
    belongType: 0,
    isTrucking: 1,
    remark: null,
    belongTable: 'roll_club_two',
    color: '#f50',
  },
  {
    id: '3',
    createBy: 'admin',
    createTime: '2024-11-19 08:56:03',
    updateBy: null,
    updateTime: null,
    sysOrgCode: null,
    castMachine: '5',
    typeName: '棒三',
    belongType: 0,
    isTrucking: 1,
    remark: null,
    belongTable: 'roll_club_three',
    color: '#87d068',
  },
  {
    id: '5',
    createBy: 'admin',
    createTime: '2024-11-19 08:56:03',
    updateBy: null,
    updateTime: null,
    sysOrgCode: null,
    castMachine: '5',
    typeName: '上若',
    belongType: 0,
    isTrucking: 1,
    remark: null,
    belongTable: 'roll_out_shipp',
    color: '#c41d7f',
  },
]
// 六号机所有目的地、堆垛配置信息
export const configAll6 = [
  {
    id: '13',
    createBy: 'admin',
    createTime: '2024-11-19 08:56:03',
    updateBy: null,
    updateTime: null,
    sysOrgCode: null,
    castMachine: '6',
    typeName: '棒二',
    belongType: 0,
    isTrucking: 1,
    remark: null,
    belongTable: 'roll_club_two',
    color: '#f50',
  },
  {
    id: '14',
    createBy: 'admin',
    createTime: '2024-11-19 08:56:03',
    updateBy: null,
    updateTime: null,
    sysOrgCode: null,
    castMachine: '6',
    typeName: '棒三',
    belongType: 0,
    isTrucking: 1,
    remark: null,
    belongTable: 'roll_club_three',
    color: '#87d068',
  },
  {
    id: '15',
    createBy: 'admin',
    createTime: '2024-11-19 08:56:03',
    updateBy: null,
    updateTime: null,
    sysOrgCode: null,
    castMachine: '6',
    typeName: '高线',
    belongType: 0,
    isTrucking: 0,
    remark: null,
    belongTable: 'roll_height',
  },
  {
    id: '16',
    createBy: 'admin',
    createTime: '2024-11-19 08:56:03',
    updateBy: null,
    updateTime: null,
    sysOrgCode: null,
    castMachine: '6',
    typeName: '上若',
    belongType: 0,
    isTrucking: 1,
    remark: null,
    belongTable: 'roll_out_shipp',
    color: '#c41d7f',
  },
  {
    id: '6',
    createBy: 'admin',
    createTime: '2024-11-19 08:56:03',
    updateBy: null,
    updateTime: null,
    sysOrgCode: null,
    castMachine: '6',
    typeName: '601堆垛',
    belongType: 1,
    isTrucking: 0,
    remark: null,
    belongTable: 'stacking_and_loading_vehicles',
  },
  {
    id: '7',
    createBy: 'admin',
    createTime: '2024-11-19 08:56:03',
    updateBy: null,
    updateTime: null,
    sysOrgCode: null,
    castMachine: '6',
    typeName: '602堆垛',
    belongType: 1,
    isTrucking: 0,
    remark: null,
    belongTable: 'stacking_and_loading_vehicles',
  },
  {
    id: '8',
    createBy: 'admin',
    createTime: '2024-11-19 08:56:03',
    updateBy: null,
    updateTime: null,
    sysOrgCode: null,
    castMachine: '6',
    typeName: '604堆垛',
    belongType: 1,
    isTrucking: 0,
    remark: null,
    belongTable: 'stacking_and_loading_vehicles',
  },
  {
    id: '9',
    createBy: 'admin',
    createTime: '2024-11-19 08:56:03',
    updateBy: null,
    updateTime: null,
    sysOrgCode: null,
    castMachine: '6',
    typeName: '步进冷床',
    belongType: 1,
    isTrucking: 0,
    remark: null,
    belongTable: 'stacking_and_loading_vehicles',
  },
]

// 根据铸机号获取配置信息
export const getMachineConfig = (machineNum: string) => {
  const res = machineNum == '6' ? configAll6 : configAll5

  const configNameList: Record<MachineConfigType, MachineConfigProps[]> = {
    [MachineConfigType.RODLINE]: [],
    [MachineConfigType.STACKING]: [],
  }
  res.forEach((item) => {
    // 确保 belongType 是 MachineConfigType 枚举类型
    if (Object.values(MachineConfigType).includes(item.belongType as MachineConfigType)) {
      configNameList[item.belongType as MachineConfigType].push(item)
    } else {
      console.warn(`Invalid belongType: ${item.belongType}`)
    }
  })

  return configNameList
}

export interface MachineConfigProps {
  id: string
  createBy: string
  createTime: string
  updateBy: string | null
  updateTime: string | null
  sysOrgCode: string | null
  castMachine: string
  typeName: string
  belongType: MachineConfigType
  isTrucking: number
  remark: string | null
  belongTable: string
  color?: string
}

export interface MConfigProps extends MachineConfigProps {
  value: string
  label: string
}

// 六号机热装
export const destinationOptions: Record<string, MConfigProps[]> = {
  '5': getMachineConfig('5')
    [MachineConfigType.RODLINE].filter((item) => item.isTrucking === 1)
    .map((item) => ({
      ...item,
      value: item.id,
      label: item.typeName,
    })),
  '6': getMachineConfig('6')
    [MachineConfigType.RODLINE].filter((item) => item.isTrucking === 1)
    .map((item) => ({
      ...item,
      value: item.id,
      label: item.typeName,
    })),
}

// 获取当前路径，判断铸机号
export const getMachineNum = (isOther?: boolean) => {
  const route = useRoute()
  const paths = route.path.split('/')
  const machineNum = paths[paths.length - 1]
  return isOther ? machineNum : ['5', '6'].includes(machineNum) ? machineNum : '6'
}

// 铸机和班组字典
export const machineDicts: Record<string, DictProps[]> = {
  lg_zj: [
    {
      value: '5',
      text: '5#机',
      color: null,
      jsonObject: null,
      title: '5#机',
      label: '5#机',
    },
    {
      value: '6',
      text: '6#机',
      color: null,
      jsonObject: null,
      title: '6#机',
      label: '6#机',
    },
  ],
  lg_bz: [
    {
      value: '1',
      text: '乙',
      color: null,
      jsonObject: null,
      title: '乙',
      label: '乙',
    },
    {
      value: '2',
      text: '丙',
      color: null,
      jsonObject: null,
      title: '丙',
      label: '丙',
    },
    {
      value: '0',
      text: '甲',
      color: null,
      jsonObject: null,
      title: '甲',
      label: '甲',
    },
    {
      value: '3',
      text: '丁',
      color: null,
      jsonObject: null,
      title: '丁',
      label: '丁',
    },
  ],
  lg_bb: [
    {
      value: '0',
      text: '白班',
      color: null,
      jsonObject: null,
      title: '白班',
      label: '白班',
    },
    {
      value: '2',
      text: '中班',
      color: null,
      jsonObject: null,
      title: '中班',
      label: '中班',
    },
    {
      value: '1',
      text: '夜班',
      color: null,
      jsonObject: null,
      title: '夜班',
      label: '夜班',
    },
  ],
}

export interface DictProps {
  value: string | number
  text: string
  color: string | number | null
  jsonObject: string | number | null
  title: string
  label: string
}

export const getMachineDict = (v: string | number, code: string) => {
  let text = ''
  const array: DictProps[] = machineDicts[code] || []
  const obj = array.filter((item) => {
    return item.value == v
  })
  if (obj.length > 0) {
    text = obj[0].text
  }

  return text || ''
}
